@@ -1,5 +1,7 @@
 import pytng
 import numpy as np
+import sys
+
 from numpy.testing import (
     assert_almost_equal,
     assert_equal,
@@ -16,8 +18,11 @@ def test_tng_example_load_bad_file(CORRUPT_FILEPATH):
             tng.read_step(0)
 
 def test_tng_example_load_utf8_special_char(TNG_UTF8_EXAMPLE):
-    with pytng.TNGFileIterator(TNG_UTF8_EXAMPLE) as tng:
-        tng.read_step(0)
+    if  sys.platform.startswith("win"):
+        pytest.skip("utf8 and windows don't mix")
+    else:
+        with pytng.TNGFileIterator(TNG_UTF8_EXAMPLE) as tng:
+            tng.read_step(0)
 
 
 def test_tng_example_open_missing_file_mode_r(MISSING_FILEPATH):
@@ -48,6 +53,26 @@ def test_tng_example_iter(TNG_EXAMPLE):
         for i, dummy in enumerate(tng):
             tng.read_step(i)
 
+def test_tng_coords_iter(TNG_COORDS_TEST):
+    with pytng.TNGFileIterator(TNG_COORDS_TEST) as tng:
+        for i, dummy in enumerate(tng):
+            tng.read_step(i)
+
+def test_tng_coords_iter(TNG_COORDS_TEST):
+    with pytng.TNGFileIterator(TNG_COORDS_TEST) as tng:
+        for i, dummy in enumerate(tng):
+            tng.read_step(i)
+
+def test_tng_coords_len(TNG_COORDS_TEST):
+    with pytng.TNGFileIterator(TNG_COORDS_TEST) as tng:
+        assert(tng.n_steps == 5)
+        assert(len(tng) == 5)
+
+def test_tng_coords_stride_frames(TNG_COORDS_TEST):
+    with pytng.TNGFileIterator(TNG_COORDS_TEST) as tng:
+        assert (np.asarray(list(tng.block_strides.values())) == 1).all()
+        assert (np.asarray(list(tng.n_data_frames.values())) == 4).all()
+
 
 @pytest.mark.parametrize(
     "slice_idx",
